/*

	Gtd Gmail
	(c) 2005 2006 Andy Mitchell [andy@gtdgmail.com]


	This code is covered by the GPL.

	My only additional terms are:

	If you utilise this code directly, please credit 'Andy Mitchell [andy@gtdgmail.com]'
	It is also a requirement to place the url, http://www.gtdgmail.com, somewhere within a public, easily accessible document (E.g. help) that ships with the sugtdequent product.
	If this code gives inspiration to your work, you may optionally wish to credit as such; 
		along with a description of what you improved and why.
		Feel free to also drop an email: I'm always interested in new projects.

*/


/*
	Cross Pollination Specialised Object
	
	Holds all specialised cross pollinations (e.g. ebay) that are available.
	
	Source data: CrossPollination_Specialised.rdf
					+ An override in the GtdOptions
		
	CpSpecialisations	->	CpNamesArray	->	Array
							CpObjects		->	Object	->	<CpObject>	->	name
																			displayName
																			urlPattern
																			isDisabled
																		
	
*/




function Gtd_getCrossPollinationSpecialisedObject(GtdOptions){

	var CpSpecialisations = new Object();

	try{
		// Pre load the disabled ones
		var DisabledPollinations = new Object();

		var disablePolliStr = GtdOptions.getOption("char", "CrossPollination.Specialisations.Disabled", "");
		if( disablePolliStr.length!=0 ){
			// Break it into an array
			var polliArray = disablePolliStr.split( String.fromCharCode(249) );
			for(var i = 0; i < polliArray.length; i++){
				DisabledPollinations[ polliArray[i] ] = true;
			}
		}


		
		
		CpSpecialisations.CpNamesArray = new Array();
		var cpNamesArrayIndex = 0;
		
		CpSpecialisations.CpObjects = new Object();
		
		// Prep the RDF reader:
		var rdfService = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);
		
		// Create the main search engine RDF file:
		var dataSource = rdfService.GetDataSourceBlocking("chrome://gtdgmail/content/CrossPollination_Specialised.rdf");
		dataSource = dataSource.QueryInterface(Components.interfaces.nsIRDFDataSource);

		var crossPollinationSpecialisations = rdfService.GetResource("http://www.gtdgmail.com/cross-pollination-specialisations/all");
		
		var name = rdfService.GetResource("http://www.gtdgmail.com/rdf/cp/name");
		var displayName = rdfService.GetResource("http://www.gtdgmail.com/rdf/cp/displayName");
		var urlPattern = rdfService.GetResource("http://www.gtdgmail.com/rdf/cp/regexPattern_Url");


		var rdfLit = Components.interfaces.nsIRDFLiteral;
		
		var cpItems = dataSource.ArcLabelsOut(crossPollinationSpecialisations);
		while (cpItems.hasMoreElements()){
		
			var predicate = cpItems.getNext();
			if (predicate instanceof Components.interfaces.nsIRDFResource){
				var cpItem = dataSource.GetTarget(crossPollinationSpecialisations, predicate, true);

				if (cpItem instanceof Components.interfaces.nsIRDFResource){
					// Read in the data:
					var str_name = dataSource.GetTarget(cpItem, name,  true);
					var str_displayName = dataSource.GetTarget(cpItem, displayName,  true);
					var str_urlPattern = dataSource.GetTarget(cpItem, urlPattern,  true);

					// Verify data:
					if (str_name instanceof rdfLit) {					

						var CurrentCpObject = null;

						// Create new object for this specialised cross pollination, and populate with properties
						var cpName = str_name.Value;
						if( !CpSpecialisations.CpObjects[cpName] ){
							CpSpecialisations.CpObjects[cpName] = new Object();
							CpSpecialisations.CpNamesArray[cpNamesArrayIndex++] = cpName;
						}
						CurrentCpObject = CpSpecialisations.CpObjects[cpName];

						CurrentCpObject.name = str_name.Value;
						if(str_displayName){
							str_displayName = str_displayName.QueryInterface(Components.interfaces.nsIRDFLiteral);
							CurrentCpObject.displayName = str_displayName.Value;
						}
						if(str_urlPattern){
							str_urlPattern = str_urlPattern.QueryInterface(Components.interfaces.nsIRDFLiteral);
							CurrentCpObject.urlPattern = new RegExp(str_urlPattern.Value);
						}
						
						if( DisabledPollinations[cpName] && DisabledPollinations[cpName]==true ){
							CurrentCpObject.isDisabled = true;
						}else{
							CurrentCpObject.isDisabled = false;
						}
					}
				}
			}
		}

	}catch(e){
		//alert(e.toString());
	}
	
	
	return CpSpecialisations;

}